==> WinBinder-0.31.104.tgz: Source/phpwb_control_treeview.c <==
/*******************************************************************************

 WINBINDER - A native Windows binding for PHP

 Copyright  2004 Hypervisual - see LICENSE.TXT for details
 Author: Rubem Pechansky (pechansky@hypervisual.com)

 ZEND wrapper for treeview control

*******************************************************************************/

//----------------------------------------------------------------- DEPENDENCIES

#include "phpwb.h"

//----------------------------------------------------------- EXPORTED FUNCTIONS

ZEND_FUNCTION(wbtemp_set_current_treeview_item)
{
	long pwbo, i1 = -1, i2 = -1;
	char *s;
	int s_len;

    if(zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC,
	  "ls|ll", &pwbo, &s, &s_len, &i1, &i2) == FAILURE)
		return;

	if(!wbIsWBObj((void *)pwbo))
		RETURN_NULL()

	RETURN_BOOL(wbSetTreeViewSelectedItem((PWBOBJ)pwbo, s, i1, i2));
}

ZEND_FUNCTION(wbtemp_create_treeview_item)
{
	long pwbo, level = 0, img1 = -1, img2 = -1;
	char *str;
	int str_len;

    if(zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC,
	  "ls|lll", &pwbo, &str, &str_len, &level, &img1, &img2) == FAILURE)
		return;

	if(!wbIsWBObj((void *)pwbo))
		RETURN_NULL()

	RETURN_LONG((LONG)wbAddItemToTree((PWBOBJ)pwbo, level, str, img1, img2));
}

ZEND_FUNCTION(wbtemp_set_treeview_image)
{
	long pwbo, hbm, n, color;

    if(zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC,
	  "llll", &pwbo, &hbm, &n, &color) == FAILURE)
		return;

	if(!wbIsWBObj((void *)pwbo))
		RETURN_NULL()

	RETURN_BOOL(wbCreateTreeViewImages((PWBOBJ)pwbo, (HBITMAP)hbm, n, color));
}

//------------------------------------------------------------------ END OF FILE

==> WinBinder-0.33.113.tgz: Source/phpwb_control_treeview.c <==
/*******************************************************************************

 WINBINDER - A native Windows binding for PHP

 Copyright  2004 Hypervisual - see LICENSE.TXT for details
 Author: Rubem Pechansky (pechansky@hypervisual.com)

 ZEND wrapper for treeview control

*******************************************************************************/

//----------------------------------------------------------------- DEPENDENCIES

#include "phpwb.h"

//----------------------------------------------------------- EXPORTED FUNCTIONS

ZEND_FUNCTION(wbtemp_set_current_treeview_item)
{
	long pwbo, i1 = -1, i2 = -1;
	char *s;
	int s_len;

    if(zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC,
	  "ls|ll", &pwbo, &s, &s_len, &i1, &i2) == FAILURE)
		return;

	if(!wbIsWBObj((void *)pwbo, TRUE))
		RETURN_NULL()

	RETURN_BOOL(wbSetTreeViewSelectedItem((PWBOBJ)pwbo, s, i1, i2));
}

ZEND_FUNCTION(wbtemp_create_treeview_item)
{
	long pwbo, level = 0, img1 = -1, img2 = -1;
	char *str;
	int str_len;

    if(zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC,
	  "ls|lll", &pwbo, &str, &str_len, &level, &img1, &img2) == FAILURE)
		return;

	if(!wbIsWBObj((void *)pwbo, TRUE))
		RETURN_NULL()

	RETURN_LONG((LONG)wbAddItemToTree((PWBOBJ)pwbo, level, str, img1, img2));
}

ZEND_FUNCTION(wbtemp_set_treeview_image)
{
	long pwbo, hbm, n, color;

    if(zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC,
	  "llll", &pwbo, &hbm, &n, &color) == FAILURE)
		return;

	if(!wbIsWBObj((void *)pwbo, TRUE))
		RETURN_NULL()

	RETURN_BOOL(wbCreateTreeViewImages((PWBOBJ)pwbo, (HBITMAP)hbm, n, color));
}

//------------------------------------------------------------------ END OF FILE
